@@ -5,7 +5,7 @@ import os
 import requests
 import logging
 
-__version__ = "1.2.0"
+__version__ = "1.2.1"
 logger = logging.getLogger("fireeye")
 
 class Detection:
@@ -56,7 +56,7 @@ class Detection:
 
   result = detection.submit_urls(
     urls={
-      "urls": "[url1,url2,...]"
+      "urls": "[\"url1\",\"url2\",...]"
     }
   )
   ```
